@@ -12,7 +12,7 @@ function(x, y, file, var.label.x, var.label.y, ...)
     onefile<- dots.args$onefile  
 
   if (is.null(file))
-    dev.new()
+    {} #dev.new()
   else {
     if (length(grep("bmp$",file)))
       bmp(file,...) 
